@@ -1,6 +1,6 @@
 
 mclustSpectra <-
-function(spectra, pca, pcs = c(1:3), dims = c(1,2), title = "no title provided",
+function(spectra, pca, pcs = c(1:3), dims = c(1,2),
 	plot = c("BIC", "proj", "error"), use.sym = FALSE, ...) {
 
 # Wrapper to mclust functions
@@ -15,9 +15,8 @@ function(spectra, pca, pcs = c(1:3), dims = c(1,2), title = "no title provided",
 	if (plot == "BIC") {
 		if (use.sym) plot(mod, d, what = "BIC", colors = "black")
 		if (!use.sym) plot(mod, d, what = "BIC")
-		title <- paste(title, ": How Many Clusters?", sep = "")
 		sub <- paste(spectra$desc, pca$method, sep = "  ")
-		title(main = title, sub = sub, cex.sub = 0.75)
+		title(sub = sub, cex.sub = 0.75)
 		mtext(note, line = - 0.5)
 		}
 		
@@ -33,9 +32,8 @@ function(spectra, pca, pcs = c(1:3), dims = c(1,2), title = "no title provided",
 				classification = mod$classification,
 				parameters = mod$parameters, colors = "black")
 			}
-		title <- paste(title, ": Clusters Found by mclust", sep = "")
 		sub <- paste(spectra$desc, pca$method, sep = "  ")
-		title(main = title, sub = sub, cex.sub = 0.75)
+		title(sub = sub, cex.sub = 0.75)
 		mtext(note, line = - 0.5)
 		}
 
@@ -43,9 +41,8 @@ function(spectra, pca, pcs = c(1:3), dims = c(1,2), title = "no title provided",
 		coordProjCS(d, dimens = dims, what = "errors",
 			classification = mod$classification, parameters = mod$parameters,
 			truth = spectra$groups, symbols = my.sym)
-		title <- paste(title, ": Misclassifications?", sep = "")
 		sub <- paste(spectra$desc, pca$method, sep = "  ")
-		title(main = title, sub = sub, cex.sub = 0.75)
+		title(sub = sub, cex.sub = 0.75)
 		mtext(note, line = - 0.5)		
 		}
 	invisible(mod)
